@@ -85,9 +85,11 @@ class Reactor(object):
             raise ProjectValidationFailedException(validation_messages)
 
     def prepare_build(self,
-                      property_overrides={},
+                      property_overrides=None,
                       project_directory=".",
                       project_descriptor="build.py"):
+        if not property_overrides:
+            property_overrides = {}
         Reactor._current_instance = self
 
         project_directory, project_descriptor = self.verify_project_directory(
@@ -108,7 +110,11 @@ class Reactor(object):
 
         self.execution_manager.resolve_dependencies()
 
-    def build(self, tasks=[], environments=[]):
+    def build(self, tasks=None, environments=None):
+        if not tasks:
+            tasks = []
+        if not environments:
+            environments = []
         Reactor._current_instance = self
 
         if environments:
@@ -233,14 +239,16 @@ class Reactor(object):
             value = getattr(self.project_module, property)
             setattr(self.project, property, value)
 
-    def load_project_module(self, project_descriptor):
+    @staticmethod
+    def load_project_module(project_descriptor):
         try:
             return imp.load_source("build", project_descriptor)
         except ImportError as e:
             raise PyBuilderException(
                 "Error importing project descriptor %s: %s" % (project_descriptor, e))
 
-    def verify_project_directory(self, project_directory, project_descriptor):
+    @staticmethod
+    def verify_project_directory(project_directory, project_descriptor):
         project_directory = os.path.abspath(project_directory)
 
         if not os.path.exists(project_directory):
